pub struct RawResource {
pub uri: String,
pub name: String,
pub title: Option<String>,
pub description: Option<String>,
pub mime_type: Option<String>,
pub size: Option<u32>,
pub icons: Option<Vec<Icon>>,
pub meta: Option<Meta>,
}Expand description
Represents a resource in the extension with metadata
Fields
uri: StringURI representing the resource location (e.g., “file:///path/to/file” or “str:///content”)
name: StringName of the resource
title: Option<String>Human-readable title of the resource
description: Option<String>Optional description of the resource
mime_type: Option<String>MIME type of the resource content (“text” or “blob”)
size: Option<u32>The size of the raw resource content, in bytes (i.e., before base64 encoding or any tokenization), if known.
This can be used by Hosts to display file sizes and estimate context window us
icons: Option<Vec<Icon>>Optional list of icons for the resource
meta: Option<Meta>Optional additional metadata for this resource
Implementations
Sourceimpl RawResource
impl RawResource