pub struct Tool {
pub name: Cow<'static, str>,
pub title: Option<String>,
pub description: Option<Cow<'static, str>>,
pub input_schema: Arc<Map<String, Value>>,
pub output_schema: Option<Arc<Map<String, Value>>>,
pub annotations: Option<ToolAnnotations>,
pub icons: Option<Vec<Icon>>,
pub meta: Option<Meta>,
}Expand description
A tool that can be used by a model.
Fields
name: Cow<'static, str>The name of the tool
title: Option<String>A human-readable title for the tool
description: Option<Cow<'static, str>>A description of what the tool does
input_schema: Arc<Map<String, Value>>A JSON Schema object defining the expected parameters for the tool
output_schema: Option<Arc<Map<String, Value>>>An optional JSON Schema object defining the structure of the tool’s output
annotations: Option<ToolAnnotations>Optional additional tool information.
icons: Option<Vec<Icon>>Optional list of icons for the tool
meta: Option<Meta>Optional additional metadata for this tool
Implementations
Sourceimpl Tool
impl Tool
Sourcepub fn new<N, D, S>(name: N, description: D, input_schema: S) -> Tool
pub fn new<N, D, S>(name: N, description: D, input_schema: S) -> Tool
Create a new tool with the given name and description
pub fn annotate(self, annotations: ToolAnnotations) -> Tool
Sourcepub fn with_output_schema<T>(self) -> Toolwhere
T: JsonSchema + 'static,
pub fn with_output_schema<T>(self) -> Toolwhere
T: JsonSchema + 'static,
Set the output schema using a type that implements JsonSchema
Panics
Panics if the generated schema does not have root type “object” as required by MCP specification.
Sourcepub fn with_input_schema<T>(self) -> Toolwhere
T: JsonSchema + 'static,
pub fn with_input_schema<T>(self) -> Toolwhere
T: JsonSchema + 'static,
Set the input schema using a type that implements JsonSchema
Sourcepub fn schema_as_json_value(&self) -> Value
pub fn schema_as_json_value(&self) -> Value
Get the schema as json value